Method: Bio::Alignment::EnumerableExtension#alignment_subseq

Defined in:
lib/bio/alignment.rb

#alignment_subseq(*arg) ⇒ Object Also known as: subseq

For each sequence, the ‘subseq’ method (Bio::Seqeunce::Common#subseq is expected) is executed, and returns a new alignment as a Bio::Alignment::SequenceArray object.

All sequences in the alignment are expected to be kind of Bio::Sequence::NA or Bio::Sequence::AA objects.

Unlike alignment_window method, the result alignment might contain nil.

If you want to change return value’s class, you should redefine alignment_collect method.



829
830
831
832
833
834
# File 'lib/bio/alignment.rb', line 829

def alignment_subseq(*arg)
  #(original)
  alignment_collect do |s|
    s.subseq(*arg)
  end
end